<?php
// Matikan pesan error Notice untuk script ini
error_reporting(E_ALL & ~E_NOTICE);

// Fungsi untuk menampilkan petunjuk penggunaan
function displayInstructions() {
    echo "<div class='instructions'>
        <h2>Petunjuk Penggunaan</h2>
        <ol>
            <li>Masukkan URL utama yang ingin digenerate di kolom 'URL'.</li>
            <li>Upload file template (.txt) yang berisi struktur HTML yang ingin digunakan (maksimal 5 slot template).</li>
            <li>Upload file .txt untuk masing-masing input:
                <ul>
                    <li>Nama brand (masukkan list Nama Toko di file .txt dengan setiap brand pada baris terpisah)</li>
                    <li>Meta description (daftar meta description dengan urutan sesuai brand)</li>
                    <li>Deskripsi domain (daftar deskripsi domain dengan urutan sesuai brand)</li>
                    <li>Keyword (Daftar keyword sesuai dengan urutan brand)</li>
                    <li>Judul (daftar judul dengan urutan sesuai brand)</li>
                    <li>URL konten (daftar URL konten dengan urutan sesuai brand)</li>
                    <li>AMP (daftar URL AMP dengan urutan sesuai brand)</li>
                    <li>URL Logo (daftar URL Logo dengan urutan sesuai brand)</li>
                    <li>URL Whastapp (daftar URL Whatsapp dengan urutan sesuai brand)</li>
                    <li>URL Telegram (daftar URL Telegram dengan urutan sesuai brand)</li>
                    <li>URL Livechat (daftar URL Livechat dengan urutan sesuai brand)</li>
                </ul>
            </li>
            <li>Masukkan 'Link Tujuan' untuk setiap tombol 'Daftar' pada template.</li>
            <li>Klik tombol 'Generate' untuk membuat file <strong>index.php</strong> di dalam folder yang dibuat berdasarkan nama brand.</li>
            <li>Periksa folder yang dibuat di path yang sama dengan tool untuk melihat hasilnya.</li>
        </ol>
        <h3>Script Khusus untuk Template</h3>
        <p>Gunakan script placeholder berikut pada file template Anda:</p>
        <ul>
            <li><code>{brand}</code> : Diganti dengan nama brand yang diupload.</li>
            <li><code>{title}</code> : Diganti dengan judul yang diupload.</li>
            <li><code>{description}</code> : Diganti dengan deskripsi domain yang diupload.</li>
            <li><code>{url}</code> : Diganti dengan URL yang diinputkan pada form.</li>
            <li><code>{content_url}</code> : Diganti dengan URL konten yang diupload.</li>
            <li><code>{logo}</code> : Diganti dengan URL Logo yang diupload.</li>
            <li><code>{Keyword}</code> : Diganti dengan list keyword yang di upload.<li>
            <li><code>{canonical}</code> : Diganti dengan canonical URL yang di-generate otomatis.</li>
            <li><code>{amp}</code> : Diganti dengan URL AMP yang di-generate otomatis.</li>
            <li><code>{og:url}</code> : Diganti dengan Open Graph URL yang di-generate otomatis.</li>
            <li><code>{og:description}</code> : Diganti dengan meta description yang diupload.</li>
            <li><code>{link_daftar}</code> : Diganti dengan 'Link Tujuan' yang diinputkan pada form.</li>
            <li><code>{link-wa}</code> : Diganti dengan 'Link Whatsapp' yang diinputkan pada form.</li>
            <li><code>{link_tele}</code> : Diganti dengan 'Link Telegram' yang diinputkan pada form.</li>
            <li><code>{link_lc}</code> : Diganti dengan 'Link Livechat' yang diinputkan pada form.</li>
            <li><code>{random_number}</code> : Diganti dengan angka acak puluhan juta.</li>
        </ul>
    </div>";
}

// Fungsi untuk membuat angka acak puluhan juta
function generateRandomNumber() {
    return number_format(rand(10000000, 99999999), 0, ',', '.');
}

// Fungsi untuk membersihkan nama folder dan URL
function sanitizeName($string) {
    return strtolower(preg_replace('/[^a-zA-Z0-9]/', '-', trim($string)));
}

// Fungsi untuk menghapus double slash "//" di URL, kecuali pada protokol (http://, https://)
function sanitizeUrl($url) {
    if (preg_match('/^https?:\/\//', $url, $matches)) {
        $protocol = $matches[0];
        $urlWithoutProtocol = substr($url, strlen($protocol));
        $urlWithoutProtocol = preg_replace('#/+#', '/', $urlWithoutProtocol);
        return $protocol . $urlWithoutProtocol;
    } else {
        return preg_replace('#/+#', '/', $url);
    }
}

// Cek apakah form sudah di-submit
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $url = rtrim($_POST['url'], '/');
    $amp = $_POST['amp'];
    $linkDaftar = $_POST['link_daftar'];
    $linkwa = $_POST['link_wa'];
    $linktele = $_POST['link_tele'];
    $linklc = $_POST['link_lc'];
    $logo = $_POST['logo'];


    // Baca semua data dari file yang di-upload dan simpan ke dalam array
    $brands = file($_FILES['brand']['tmp_name'], FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
    $titles = file($_FILES['title']['tmp_name'], FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
    $metaDescriptions = file($_FILES['meta_description']['tmp_name'], FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
    $keywords = file($_FILES['keyword']['tmp_name'], FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
    $domainDescriptions = file($_FILES['domain_description']['tmp_name'], FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
    $contentUrls = file($_FILES['content_url']['tmp_name'], FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);

    // Baca semua template yang di-upload (hingga maksimal 5 template)
    $templates = [];
    for ($j = 1; $j <= 5; $j++) {
        if (!empty($_FILES["template_$j"]['tmp_name'])) {
            $templates[] = file_get_contents($_FILES["template_$j"]['tmp_name']);
        }
    }

    // Pastikan semua file memiliki setidaknya satu template
    if (empty($templates)) {
        echo "<script>alert('Minimal satu template harus diupload.');</script>";
        exit();
    }

    // Cek jumlah baris terbesar dan sesuaikan data
    $totalEntries = max(count($brands), count($titles), count($metaDescriptions),count($keywords), count($domainDescriptions), count($contentUrls));

    // Loop untuk setiap brand di dalam daftar
    for ($i = 0; $i < $totalEntries; $i++) {
        $brand = trim($brands[$i % count($brands)]); // Looping jika jumlah list lebih sedikit
        $title = trim($titles[$i % count($titles)]);
        $metaDescription = trim($metaDescriptions[$i % count($metaDescriptions)]);
        $keyword = trim($keywords[$i % count($keywords)]);
        $domainDescription = trim($domainDescriptions[$i % count($domainDescriptions)]);
        $contentUrl = trim($contentUrls[$i % count($contentUrls)]);

        // Membersihkan nama brand untuk dijadikan nama folder dan URL
        $cleanBrand = sanitizeName($title);

        // Buat folder berdasarkan nama brand yang sudah di-clean (di path yang sama dengan tools ini)
        if (!file_exists($cleanBrand)) {
            mkdir($cleanBrand, 0777, true);
        }

        // Buat URL unik untuk setiap folder yang sudah di-clean
        $uniqueUrl = sanitizeUrl($url . '/' . $cleanBrand);

        // Pilih template secara bergantian
        $template = $templates[$i % count($templates)];

        // Ganti placeholder dalam template dengan data yang diunggah
        $templateModified = str_replace('{brand}', $brand, $template);
        $templateModified = str_replace('{title}', $title, $templateModified);
        $templateModified = str_replace('{description}', $domainDescription, $templateModified);
        $templateModified = str_replace('{url}', $uniqueUrl, $templateModified);
        $templateModified = str_replace('{content_url}', $contentUrl, $templateModified);
        $templateModified = str_replace('{keyword}', $keyword, $templateModified);
        $templateModified = str_replace('{canonical}', $uniqueUrl, $templateModified);
        $templateModified = str_replace('{og:url}', $uniqueUrl, $templateModified);
        $templateModified = str_replace('{og:description}', $metaDescription, $templateModified);
        $templateModified = str_replace('{logo}', sanitizeUrl($logo), $templateModified);
        $templateModified = str_replace('{amp}', sanitizeUrl($amp), $templateModified);
        $templateModified = str_replace('{link_daftar}', sanitizeUrl($linkDaftar), $templateModified);
        $templateModified = str_replace('{link_wa}', sanitizeUrl($linkwa), $templateModified);
        $templateModified = str_replace('{link_tele}', sanitizeUrl($linktele), $templateModified);
        $templateModified = str_replace('{link_lc}', sanitizeUrl($linklc), $templateModified);
        $templateModified = str_replace('{random_number}', generateRandomNumber(), $templateModified);

        // Tambahkan error_reporting di dalam file index.php yang digenerate untuk menonaktifkan Notice
        $templateModified = "<?php error_reporting(E_ALL & ~E_NOTICE); ?>\n" . $templateModified;

        // Simpan template yang sudah diubah menjadi index.php di folder brand
        $filePath = $cleanBrand . '/index.php';
        if (file_put_contents($filePath, $templateModified)) {
            echo "<script>console.log('File index.php berhasil dibuat di folder $cleanBrand');</script>";
        } else {
            echo "<script>alert('Gagal membuat file index.php di folder $cleanBrand');</script>";
        }
    }

    echo "<script>alert('Semua file index.php berhasil dibuat di masing-masing folder brand.');</script>";
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Tools Generator Landing Page</title>
    <link rel="icon" href="https://enak.la/images/2024/11/18/royal-web-size.png" type="image/png">
    <style>
        /* Background */
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 20px;
            transition: background-color 0.5s ease-in-out;
            background: url('https://enak.la/images/2024/11/18/bgapi.jpeg') no-repeat center center fixed;
            background-size: cover;
            color: #333;
        }

        .container {
            max-width: 800px;
            margin: auto;
            background: rgba(255, 255, 255, 0.8);
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 0 20px rgba(0, 0, 0, 0.1);
        }

        h1 {
            text-align: center;
            color: #1976ed;
        }

        .form-group {
            margin-bottom: 20px;
        }

        .form-group label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
        }

        .form-group input[type="file"],
        .form-group input[type="text"] {
            width: 100%;
            padding: 10px;
            border: 1px solid #ccc;
            border-radius: 4px;
        }

        .form-group input[type="submit"] {
            background: #1976ed;
            color: white;
            border: none;
            padding: 15px;
            border-radius: 4px;
            cursor: pointer;
            position: relative;
            overflow: hidden;
            transition: background 0.3s, box-shadow 0.3s;
        }

        .form-group input[type="submit"]:hover {
            background: #1565c0;
            box-shadow: 0 0 10px #1565c0;
        }

        .instructions {
            background: rgba(249, 249, 249, 0.8);
            padding: 20px;
            margin: 20px 0;
            border-radius: 4px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        .toggle-mode {
            text-align: center;
            margin: 20px 0;
        }

        .toggle-mode button {
            padding: 10px 20px;
            background: #333;
            color: #fff;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            transition: background 0.3s;
        }

        .toggle-mode button:hover {
            background: #555;
            box-shadow: 0 0 10px #555;
        }

        .dark-mode {
            background: radial-gradient(ellipse at bottom, #0d1d31 0%, #0c0d13 100%);
            color: #fff;
        }

        .dark-mode .container {
            background: rgba(66, 66, 66, 0.9);
        }

        .dark-mode .instructions {
            background: rgba(66, 66, 66, 0.9);
        }

        .dark-mode .form-group input[type="file"],
        .dark-mode .form-group input[type="text"] {
            border: 1px solid #555;
            background: #555;
            color: #fff;
        }

        .dark-mode .form-group input[type="submit"] {
            background: #007bff;
        }

        .dark-mode .form-group input[type="submit"]:hover {
            background: #0056b3;
            box-shadow: 0 0 10px #0056b3;
        }

        /* Stars Animation */
        .stars {
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 120%;
            transform: rotate(-45deg);
        }

        .star {
            --star-color: var(--primary-color);
            --star-tail-length: 6em;
            --star-tail-height: 2px;
            --star-width: calc(var(--star-tail-length) / 6);
            --fall-duration: 9s;
            --tail-fade-duration: var(--fall-duration);

            position: absolute;
            top: var(--top-offset);
            left: 0;
            width: var(--star-tail-length);
            height: var(--star-tail-height);
            color: var(--star-color);
            background: linear-gradient(45deg, currentColor, transparent);
            border-radius: 50%;
            filter: drop-shadow(0 0 6px currentColor);
            transform: translate3d(104em, 0, 0);
            animation: fall var(--fall-duration) var(--fall-delay) linear infinite, tail-fade var(--tail-fade-duration) var(--fall-delay) ease-out infinite;
        }

        @keyframes fall {
            to {
                transform: translate3d(-30em, 0, 0);
            }
        }

        @keyframes tail-fade {
            0%, 50% {
                width: var(--star-tail-length);
                opacity: 1;
            }
            70%, 80% {
                width: 0;
                opacity: 0.4;
            }
            100% {
                width: 0;
                opacity: 0;
            }
        }

        @keyframes blink {
            50% {
                opacity: 0.6;
            }
        }
    </style>
</head>
<body>
<div class="container">
    <img src="https://enak.la/images/2024/11/18/royal-web-size.png" alt="Logo" style="display: block; margin: 0 auto 20px;">
    <h1>Tools Generator Landing Page</h1>
    <form method="POST" enctype="multipart/form-data">
        <div class="form-group">
            <label for="url">URL:</label>
            <input type="text" id="url" name="url" required>
        </div>
        <div class="form-group">
            <label for="amp">AMP:</label>
            <input type="text" id="amp" name="amp" required>
        </div>
        <div class="form-group">
            <label for="link_daftar">Link Tujuan untuk Tombol Daftar:</label>
            <input type="text" id="link_daftar" name="link_daftar" required>
        </div>
        <div class="form-group">
            <label for="logo">LOGO:</label>
            <input type="text" id="logo" name="logo" required>
        </div>
        <div class="form-group">
            <label for="link_wa">Link whatsapp:</label>
            <input type="text" id="link_wa" name="link_wa" required>
        </div>
        <div class="form-group">
            <label for="link_tele">Link Telegram:</label>
            <input type="text" id="link_tele" name="link_tele" required>
        </div>
        <div class="form-group">
            <label for="link_lc">Link Livechat:</label>
            <input type="text" id="link_lc" name="link_lc" required>
        </div>
        <div class="form-group">
            <label for="template_1">Upload Template 1 (TXT):</label>
            <input type="file" id="template_1" name="template_1" accept=".txt" required>
        </div>
        <div class="form-group">
            <label for="template_2">Upload Template 2 (TXT):</label>
            <input type="file" id="template_2" name="template_2" accept=".txt">
        </div>
        <div class="form-group">
            <label for="template_3">Upload Template 3 (TXT):</label>
            <input type="file" id="template_3" name="template_3" accept=".txt">
        </div>
        <div class="form-group">
            <label for="template_4">Upload Template 4 (TXT):</label>
            <input type="file" id="template_4" name="template_4" accept=".txt">
        </div>
        <div class="form-group">
            <label for="template_5">Upload Template 5 (TXT):</label>
            <input type="file" id="template_5" name="template_5" accept=".txt">
        </div>

        <div class="form-group">
            <label for="brand">Upload Brand Name List (TXT):</label>
            <input type="file" id="brand" name="brand" accept=".txt" required>
        </div>
        <div class="form-group">
            <label for="title">Upload Title (TXT):</label>
            <input type="file" id="title" name="title" accept=".txt" required>
        </div>
        <div class="form-group">
            <label for="meta_description">Upload Meta Description (TXT):</label>
            <input type="file" id="meta_description" name="meta_description" accept=".txt" required>
        </div>
        <div class="form-group">
            <label for="domain_description">Upload Domain Description (TXT):</label>
            <input type="file" id="domain_description" name="domain_description" accept=".txt" required>
        </div>
        <div class="form-group">
            <label for="keyword">Upload Keyword (TXT):</label>
            <input type="file" id="keyword" name="keyword" accept=".txt" required>
        </div>
        <div class="form-group">
            <label for="content_url">Upload Content URL (TXT):</label>
            <input type="file" id="content_url" name="content_url" accept=".txt" required>
        </div>
        <div class="form-group">
            <input type="submit" value="Generate">
        </div>
    </form>
</div>
<div class="toggle-mode">
    <button onclick="toggleMode()">Toggle Dark/Light Mode</button>
</div>
<div class="instructions">
    <?php displayInstructions(); ?>
</div>
<script>
    function toggleMode() {
        document.body.classList.toggle('dark-mode');
    }
</script>
</body>
</html>
